// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// backscale.cc
//
// Authors:  Richard Saxton (VEGA/ESA)
//           ESA XMM SOC
//
// Description: Metatask for running arfgen to produce BACKSCAL keyword
//
//#include <set>          // C++
//#include <algorithm>
//#include <strstream.h>
//#include <unistd.h>
#include <Tracer.h>
#include <metatask.h>
#include <errstr.h>
#include <param.h>

#include <arfgen.h>   // tasks

#include "backscale.h"

void backscale()
{
  PROC

  /* Get the parameters from this command line */
    string spectrumset = stringParameter("spectrumset");
    bool withbadpixcorr = booleanParameter("withbadpixcorr");
    bool useodfatt = booleanParameter("useodfatt");
    bool ignoreoutoffov= booleanParameter("ignoreoutoffov");
    string badpixlocation = stringParameter("badpixlocation");
    //string detmaptype = stringParameter("detmaptype");
    //string detmaparray = stringParameter("detmaparray");

  /* Set up the parameters for calling arfgen */
    openParameters("arfgen");

  /* First the input parameters */
    setParameter("spectrumset",spectrumset);
    setParameter("withbadpixcorr",withbadpixcorr);
    setParameter("useodfatt",useodfatt);
    setParameter("ignoreoutoffov",ignoreoutoffov);
    setParameter("badpixlocation",badpixlocation);
    //setParameter("detmaptype",detmaptype);
    //setParameter("detmaparray",detmaparray);

  /* Set the other parameters */
    setParameter("withrmfset",false);
    setParameter("arfset","deletearf.ds");
    setParameter("withdetbounds",false);
    setParameter("detxbins",1);            // Use the minimum detector map
    setParameter("detybins",1);
    setParameter("extendedsource",true);   // Use extended source logic
    setParameter("modeleffarea",false);
    setParameter("modelquantumeff",false);
    setParameter("modelfiltertrans",false);
    setParameter("modelee",false);
    setParameter("setbackscale",true); // Set the backscale value
    setParameter("keeparfset",false); // Throw away the generated arf file

  /* Now run arfgen using these parameters */ 
    task(arfgen);
   
  /* Shutdown */
    closeParameters();

  ENDPROC
}

